\name{cbcrisk}
\alias{cbcrisk}

\title{ predicts the risk of contralateral breast cancer
}
\description{
\code{cbcrisk} is used to predict the chance of developing contralateral breast cancer for a woman whose current age (i.e., age at counseling) is within 18-89. This function gives the predictions starting at the current age (\code{start.age}) and then in increments of a specified number of years (\code{pred.year}) up to age 89.
}
\usage{
cbcrisk(profile, start.age, pred.year, print.output)
}
\arguments{
  \item{profile}{
  a vector containing the values of 8 variables in the following order: 
  Age at first breast cancer (BC) diagnosis, Anti-estrogen therapy, Family history of BC, High Risk Preneoplasia status, Breast density (BI-RADS), Estrogen Receptor (ER) status, First BC type and Age at first birth. The possible values (categories) of each variable are listed below in the Details section. 
  
}
  \item{start.age}{
  current age (i.e., age at couselling) of the woman. It must be equal to or greater than the age at first breast cancer diagnosis.
}
  \item{pred.year}{
increments (in years) at which the predictions will be made, starting at \code{start.age} up to age 89. 
e.g; 2, 5, 10, ... . The default is 5 years. 
}
\item{print.output}{
a logical indicating whether the output should be printed on R console. Defaults to TRUE. Setting it to FALSE suppresses the output.
}

}
\details{ 
The \code{cbcrisk} function needs a vector of length 8 as a patient profile. The elements of the patient profile vector must consist of the numerical codes of the categories (noted in parentheses below) of the following risk factors:

Age at first BC diagnosis: <30 (1); 30-39 (2); 40+ (3).   	
	
Anti-estrogen therapy:	Yes	(1); No (2); Unknown	(3).
		
1st degree family history of BC: 	Yes	(1); No (2); Unknown (3).
		
High Risk Preneoplasia: Yes	(1); No/Unknown	(2).
		
Breast density:	Extreme dense (1); Heterogeneously dense (2); Scattered	(3); Almost Entirely fat (4); Unknown	(5).
		
ER status:	Negative (1); Positive (2); Unknown	(3).
		
First BC type: Pure DCIS (1); Mixed	(2); Pure Invasive (3).
		
Age at first birth:	<30/Nulliparous	(1); 30-39 (2); 40+ (3); Unknown (4).
}

\value{
\code{cbcrisk} returns a list of three objects--- the patient profile provided by the user, the current age of the woman provided by the user, and the contralateral breast cancer risks until age 89.

 \item{profile}{the patient profile containing information about the 8 variables discussed above.}
 
 \item{current.age}{current age of the woman.}
 
 \item{risk}{the risks of contralateral breast cancer up to age 89.}
}

\references{
1. Chowdhury, M., Euhus, D., Onega, T., Biswas, S. and Choudhary, P. K. (2017) A model for individualized risk prediction of contralateral breast cancer, Breast Cancer Research and Treatment, 161, 153-160. 

2. Chowdhury, M., Euhus, D., Banu, A., Umbricht, C., Biswas, S. and Choudhary, P. K. (2018) Validation of a Personalized Risk Prediction Model for Contralateral Breast Cancer, Breast Cancer Research and Treatment, 170, 415-423.

3. Chowdhury, M., Euhus, D., O'Donnell, M., Onega, T., Choudhary, P. K. and Biswas, S. (2018) Dose-Dependent Effect of Mammographic Breast Density on the Risk of Contralateral Breast Cancer, Breast Cancer Research and Treatment, 170, 143-148.


}
\author{
Marzana Chowdhury
}


\examples{
## The profile vector 
patient_profile= c(3, 2, 1, 2, 3, 2, 1, 2)

## install packages "survival" (if not already installed)
## install the "CBCRisk" package

library(CBCRisk)
cbcrisk(patient_profile, 55)  #### risks at every 5 years (by default) starting at age 55
cbcrisk(patient_profile, 55, 10) ### risks at every 10 years starting at age 55

}
